@@ -323,7 +323,7 @@ totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 	}
 
 	if (state == TOTEM_STATE_PLAYING) {
-		if (emb->inhibit_id == 0) {
+		if (emb->inhibit_id == 0 && GTK_IS_PLUG (emb->window)) {
 			emb->inhibit_id = gtk_application_inhibit (GTK_APPLICATION (emb),
 								   NULL,
 								   GTK_APPLICATION_INHIBIT_IDLE,
@@ -1724,8 +1724,6 @@ totem_embedded_construct (TotemEmbedded *emb,
 	container = GTK_WIDGET (gtk_builder_get_object (emb->xml, "video_box"));
 
 	gtk_container_add (GTK_CONTAINER (container), GTK_WIDGET (emb->bvw));
-	/* FIXME: why can't this wait until the whole window is realised? */
-	gtk_widget_realize (GTK_WIDGET (emb->bvw));
 	gtk_widget_show (GTK_WIDGET (emb->bvw));
 
 	/* FIXME disable video decoding when hidden */
@@ -2222,6 +2220,9 @@ int main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+	/* Work around Chromium setting GDK_NATIVE_WINDOWS */
+	g_unsetenv ("GDK_NATIVE_WINDOWS");
+
 	g_set_application_name (_("Movie browser plugin"));
 	gtk_window_set_default_icon_name ("totem");
 
@@ -2247,15 +2248,14 @@ int main (int argc, char **argv)
 
 		env = g_getenv ("TOTEM_EMBEDDED_GDB");
 		if (env && g_ascii_strtoull (env, NULL, 10) == 1) {
-			const char *gdbargv[5];
+			const char *gdbargv[4];
 			char *gdb;
 			GError *gdberr = NULL;
 			int gdbargc = 0;
 
-			gdb = g_strdup_printf ("gdb %s %d", argv[0], getpid ());
+			gdb = g_strdup_printf ("/usr/bin/gdb %s %d", argv[0], getpid ());
 
 			gdbargv[gdbargc++] = "/usr/bin/gnome-terminal";
-			gdbargv[gdbargc++] = "--disable-factory";
 			gdbargv[gdbargc++] = "-e";
 			gdbargv[gdbargc++] = gdb;
 			gdbargv[gdbargc++] = NULL;
