@@ -1100,6 +1100,9 @@ find_media_cb (GtkTreeModel  *model,
 	gtk_tree_model_get (model, iter,
 			    MODEL_RESULTS_CONTENT, &media,
 			    -1);
+	if (!media)
+		return FALSE;
+
 	if (g_strcmp0 (grl_media_get_id (media), grl_media_get_id (data->media)) == 0) {
 		g_object_unref (media);
 		data->found = TRUE;
@@ -1614,13 +1617,16 @@ window_key_press_event_cb (GtkWidget   *win,
 			   GdkEventKey *event,
 			   TotemGrilo  *self)
 {
+	guint state;
+
 	/* Check whether we're in the browse panel */
 	if (!g_str_equal (totem_object_get_main_page (self->priv->totem), "grilo"))
 		return GDK_EVENT_PROPAGATE;
 
+	state = event->state & gtk_accelerator_get_default_mod_mask ();
+
 	/* Handle Ctrl+F */
-	if (event->state != 0 &&
-	    (event->state & GDK_CONTROL_MASK)) {
+	if (state == GDK_CONTROL_MASK) {
 		if (event->keyval == GDK_KEY_F ||
 		    event->keyval == GDK_KEY_f) {
 			gtk_search_bar_set_search_mode (GTK_SEARCH_BAR (self->priv->search_bar),
@@ -1629,6 +1635,13 @@ window_key_press_event_cb (GtkWidget   *win,
 		}
 	}
 
+	if (state == 0 &&
+	    event->keyval == GDK_KEY_Escape &&
+	    gd_main_view_get_selection_mode (GD_MAIN_VIEW (self->priv->browser))) {
+		gd_main_view_set_selection_mode (GD_MAIN_VIEW (self->priv->browser), FALSE);
+		return GDK_EVENT_STOP;
+	}
+
 	return gtk_search_bar_handle_event (GTK_SEARCH_BAR (self->priv->search_bar), (GdkEvent *) event);
 }
 
@@ -1978,7 +1991,6 @@ play_selection (TotemGrilo *self,
 {
 	GtkTreeModel *model;
 	GList *list;
-	gboolean first = TRUE;
 	GPtrArray *items;
 	guint i;
 
@@ -1998,6 +2010,7 @@ play_selection (TotemGrilo *self,
 	g_list_free (list);
 
 	totem_object_clear_playlist (self->priv->totem);
+	list = NULL;
 
 	for (i = 0; i < items->len; i++) {
 		GtkTreePath *path = items->pdata[i];
@@ -2022,10 +2035,8 @@ play_selection (TotemGrilo *self,
 		}
 
 		title = get_title (media);
-		totem_object_add_to_playlist (self->priv->totem, url,
-					      title, first);
+		list = g_list_prepend (list, totem_playlist_mrl_data_new (url, title));
 		g_free (title);
-		first = FALSE;
 
 next_item:
 		g_clear_object (&media);
@@ -2033,6 +2044,9 @@ next_item:
 	}
 
 	g_ptr_array_free (items, FALSE);
+
+	totem_object_add_items_to_playlist (self->priv->totem, g_list_reverse (list));
+
 	g_object_set (G_OBJECT (self->priv->browser), "selection-mode", FALSE, NULL);
 }
 
